@@ -22,13 +22,11 @@
 
 #include <config.h>
 
-#define DRAGONPLAYER_DEBUG_PREFIX "engine"
 
 #include "videoWindow.h"
 #include "timeLabel.h"
 
 #include "actions.h"        //::seek() FIXME unfortunate
-#include "debug.h"
 #include "theStream.h"
 
 #ifdef HAVE_XINE
@@ -43,6 +41,7 @@
 #include <QPainter>
 
 #include <KApplication>
+#include <KDebug>
 #include <KIcon>
 #include <KLocale>
 #include <KMenu>
@@ -50,6 +49,7 @@
 #include <KStandardDirs>
 
 #include <Phonon/AudioOutput>
+#include <phonon/audiodataoutput.h>
 #include <Phonon/MediaController>
 #include <Phonon/MediaObject>
 #include <Phonon/MediaSource>
@@ -92,13 +92,13 @@ VideoWindow::VideoWindow( QWidget *parent )
         , m_subLanguages( new QActionGroup( this ) )
         , m_audioLanguages( new QActionGroup( this ) )
         , m_logo( new QLabel( this ) )
+        , m_aDataOutput(0)
 {
-    DEBUG_BLOCK
-    
+
     m_isPreview = false;
 
     s_instance = this;
-    setObjectName( "VideoWindow" );
+    setObjectName( QLatin1String( "VideoWindow" ) );
 
     QVBoxLayout *box = new QVBoxLayout( this );
     box->setMargin(0);
@@ -167,7 +167,6 @@ VideoWindow::VideoWindow( QWidget *parent )
 
 VideoWindow::~VideoWindow()
 {
-    DEBUG_BLOCK
 
     eject();
     KConfigGroup config = KGlobal::config()->group( "General" );
@@ -198,15 +197,14 @@ VideoWindow::init()
 bool
 VideoWindow::load( const KUrl &url )
 {
-    DEBUG_BLOCK
 
     QApplication::setOverrideCursor( Qt::WaitCursor );
 
     eject();
 
     KMimeType::Ptr mimeType = KMimeType::findByUrl( url );
-    debug() << "detected mimetype: " << mimeType->name();
-    if( mimeType->is( "application/x-cd-image" ) || mimeType->is( "inode/directory" ) )
+    kDebug() << "detected mimetype: " << mimeType->name();
+    if( mimeType->is( QLatin1String( "application/x-cd-image" ) ) || mimeType->is( QLatin1String( "inode/directory" ) ) )
         m_media->setCurrentSource( Phonon::MediaSource( Phonon::Dvd, url.path() ) );
     else
         m_media->setCurrentSource( url );
@@ -222,7 +220,6 @@ VideoWindow::load( const KUrl &url )
 bool
 VideoWindow::play( qint64 offset )
 {
-    DEBUG_BLOCK
 
     QApplication::setOverrideCursor( Qt::WaitCursor );
 
@@ -230,7 +227,7 @@ VideoWindow::play( qint64 offset )
     if( offset > 0 )
         seek( offset );
     m_media->play();
-    debug() << "Does this media have Video stream? " << TheStream::hasVideo();
+    kDebug() << "Does this media have Video stream? " << TheStream::hasVideo();
 
     QApplication::restoreOverrideCursor();
 
@@ -263,7 +260,6 @@ VideoWindow::playDvd()
 bool
 VideoWindow::playDisc(const Solid::Device& device )
 {
-DEBUG_BLOCK
     QString devicePath;
     {
         const Solid::Block* block = device.as<const Solid::Block>();
@@ -271,7 +267,7 @@ DEBUG_BLOCK
             devicePath = block->device();
         else
         {
-            debug() << "device was not a block";
+            kDebug() << "device was not a block";
             return false;
         }
     }
@@ -289,24 +285,24 @@ DEBUG_BLOCK
                 phononType = Phonon::Cd;
             else
             {
-                debug() << "not a playable disc type: " << disc->availableContent() << " type";
+                kDebug() << "not a playable disc type: " << disc->availableContent() << " type";
                 return false;
             }
         }
         eject();
         m_media->setCurrentSource( Phonon::MediaSource( phononType, devicePath ) );
-        debug() << "actually playing the disc at " << devicePath;
+        kDebug() << "actually playing the disc at " << devicePath;
         m_media->play();
         return true;
     }
     else
     {
-        debug() << "device was not a disc";
+        kDebug() << "device was not a disc";
         return false;
     }
 }
 
-bool 
+bool
 VideoWindow::isPreview(const bool &v)
 {
    if( v )
@@ -319,7 +315,7 @@ VideoWindow::isPreview(const bool &v)
 void
 VideoWindow::relativeSeek( qint64 step )
 {
-    debug() << "** relative seek";
+    kDebug() << "** relative seek";
     const qint64 new_pos = currentTime() + step;
     if( ( new_pos >= 0 ) && ( new_pos < length() ) )
     {
@@ -336,11 +332,11 @@ VideoWindow::relativeSeek( qint64 step )
 void
 VideoWindow::stop()
 {
-    debug() << "Stop called";
+    kDebug() << "Stop called";
     eject();
     m_media->stop();
     m_media->setCurrentSource(Phonon::MediaSource()); //set the current source to    Phonon::MediaSource::Empty
-    debug() << "Media source valid? "<<  TheStream::hasMedia();
+    kDebug() << "Media source valid? "<<  TheStream::hasMedia();
       m_vWidget->hide();
     m_logo->show();
 }
@@ -368,7 +364,7 @@ VideoWindow::urlOrDisc() const
     {
         case Phonon::MediaSource::Invalid:
         case Phonon::MediaSource::Empty:
-            return "Invalid"; //no i18n, used for DBus responses
+            return QLatin1String( "Invalid" ); //no i18n, used for DBus responses
             break;
         case Phonon::MediaSource::Url:
         case Phonon::MediaSource::LocalFile:
@@ -378,12 +374,12 @@ VideoWindow::urlOrDisc() const
             return source.deviceName();
             break;
         case Phonon::MediaSource::Stream:
-            return "Data Stream";
+            return QLatin1String( "Data Stream" );
             break;
         default:
             break;
     }
-    return "Error";
+    return QLatin1String( "Error" );
 }
 
 QMultiMap<QString, QString>
@@ -432,7 +428,6 @@ VideoWindow::isMuted()
 void
 VideoWindow::seek( qint64 pos )
 {
-    DEBUG_BLOCK
 //    bool wasPaused = false;
 
     // If we seek to the end the track ended event is sent, but it is
@@ -471,6 +466,20 @@ VideoWindow::length() const
     return m_media->totalTime();
 }
 
+bool
+VideoWindow::setupAnalyzer(QObject* analyzer)
+{
+    if(!m_aDataOutput)
+    {
+        m_aDataOutput = new Phonon::AudioDataOutput(this);
+        m_audioDataPath = Phonon::createPath(m_media, m_aDataOutput);
+        connect(m_aDataOutput, SIGNAL(dataReady(const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> >&)),
+                analyzer,  SLOT(drawFrame(const QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >&)));
+    }
+
+    return m_audioDataPath.isValid();
+}
+
 bool
 VideoWindow::isDVD() const
 {
@@ -481,6 +490,7 @@ QWidget*
 VideoWindow::newPositionSlider()
 {
     SeekSlider *seekSlider = new SeekSlider();
+    seekSlider->setIconVisible( false );
     seekSlider->setMediaObject( m_media );
     seekSlider->setSingleStep( 5000 );
     return seekSlider;
@@ -490,7 +500,7 @@ QWidget*
 VideoWindow::newVolumeSlider()
 {
     VolumeSlider *volumeSlider = new VolumeSlider();
-    volumeSlider->setObjectName( "volume" );
+    volumeSlider->setObjectName( QLatin1String( "volume" ) );
     volumeSlider->setAudioOutput( m_aOutput );
     volumeSlider->setMuteVisible( false );
     volumeSlider->setOrientation( Qt::Vertical );
@@ -500,16 +510,15 @@ VideoWindow::newVolumeSlider()
 void
 VideoWindow::refreshXineStream()
 {
-DEBUG_BLOCK
    if( m_media->property( "xine_stream_t" ).canConvert<void*>() )
   //  if( m_media->property( "xine_stream_t" ).isValid() )
     {
-        debug() << "value property " <<  m_media->property( "xine_stream_t" ).type();
+        kDebug() << "value property " <<  m_media->property( "xine_stream_t" ).type();
         m_xineStream = (xine_stream_t*) m_media->property( "xine_stream_t" ).value<void*>();
     }
     else
     {
-        debug() << "mrrrrrr, QVariant property xine_stream_t isn't a void*.";
+        kDebug() << "mrrrrrr, QVariant property xine_stream_t isn't a void*.";
         m_xineStream = 0;
     }
 }
@@ -517,11 +526,10 @@ DEBUG_BLOCK
 void
 VideoWindow::stateChanged(Phonon::State currentState, Phonon::State oldstate) // slot
 {
-DEBUG_BLOCK
-debug() << "chapters: " << m_controller->availableChapters() << " titles: " << m_controller->availableTitles();
+kDebug() << "chapters: " << m_controller->availableChapters() << " titles: " << m_controller->availableTitles();
     QStringList states;
-    states << "Loading" << "Stopped" << "Playing" << "Buffering" << "Paused" << "Error";
-    debug() << "going from " << states.at(oldstate) << " to " << states.at(currentState);
+    states << QLatin1String( "Loading" ) << QLatin1String( "Stopped" ) << QLatin1String( "Playing" ) << QLatin1String( "Buffering" ) << QLatin1String( "Paused" ) << QLatin1String( "Error" );
+    kDebug() << "going from " << states.at(oldstate) << " to " << states.at(currentState);
 
     if( currentState == Phonon::LoadingState )
       m_xineStream = 0;
@@ -538,7 +546,7 @@ debug() << "chapters: " << m_controller->availableChapters() << " titles: " << m
            if( mainWindow() )
              ( (QWidget*) mainWindow() )->adjustSize();
           m_adjustedSize=true;
-          debug() << "adjusting size to video resolution";
+          kDebug() << "adjusting size to video resolution";
         }
     }
     emit stateUpdated( currentState, oldstate );
@@ -549,20 +557,20 @@ VideoWindow::settingChanged( int setting )
 {
     const QString name = sender()->objectName();
     const double dSetting = static_cast<double>( setting ) * 0.01;
-    debug() << "setting " << name << " to " << dSetting;
-    if( name == "brightnessSlider" )
+    kDebug() << "setting " << name << " to " << dSetting;
+    if( name == QLatin1String( "brightnessSlider" ) )
     {
         m_vWidget->setBrightness( dSetting );
     }
-    else if( name == "contrastSlider" )
+    else if( name == QLatin1String( "contrastSlider" ) )
     {
         m_vWidget->setContrast( dSetting );
     }
-    else if( name == "hueSlider" )
+    else if( name == QLatin1String( "hueSlider" ) )
     {
         m_vWidget->setHue( dSetting );
     }
-    else if( name == "saturationSlider" )
+    else if( name == QLatin1String( "saturationSlider" ) )
     {
         m_vWidget->setSaturation( dSetting );
     }
@@ -603,7 +611,7 @@ VideoWindow::updateActionGroup( QActionGroup* channelActions
     foreach( const ChannelDescription &channel, availableChannels )
     {
         QAction* lang = new QAction( channelActions );
-        debug() << "the text is: \"" << channel.name() << "\" and index " << channel.index();
+        kDebug() << "the text is: \"" << channel.name() << "\" and index " << channel.index();
         lang->setCheckable( true );
         lang->setText( channel.name() );
         lang->setProperty( TheStream::CHANNEL_PROPERTY, channel.index() );
@@ -614,7 +622,6 @@ VideoWindow::updateActionGroup( QActionGroup* channelActions
 void
 VideoWindow::updateChannels()
 {
-    DEBUG_BLOCK
     updateActionGroup( m_subLanguages, m_controller->availableSubtitles(), SLOT( slotSetSubtitle() ) );
     emit subChannelsChanged( m_subLanguages->actions() );
     updateActionGroup( m_audioLanguages, m_controller->availableAudioChannels(), SLOT( slotSetAudio() ) );
@@ -624,7 +631,6 @@ VideoWindow::updateChannels()
 void
 VideoWindow::hideCursor()
 {
-   DEBUG_BLOCK
    if(m_media->hasVideo() && m_vWidget->underMouse() )
        kapp->setOverrideCursor( Qt::BlankCursor );
 }
@@ -632,9 +638,8 @@ VideoWindow::hideCursor()
 void
 VideoWindow::setSubtitle( int channel )
 {
-    DEBUG_BLOCK
     Phonon::SubtitleDescription desc = Phonon::SubtitleDescription::fromIndex( channel );
-    debug() << "using index: " << channel << " returned desc has index: " << desc.index();
+    kDebug() << "using index: " << channel << " returned desc has index: " << desc.index();
     if(desc.isValid())
       m_controller->setCurrentSubtitle( desc );
 }
@@ -642,7 +647,6 @@ VideoWindow::setSubtitle( int channel )
 void
 VideoWindow::slotSetSubtitle()
 {
-    DEBUG_BLOCK
     if( sender() && sender()->property( TheStream::CHANNEL_PROPERTY ).canConvert<int>() )
         setSubtitle( sender()->property( TheStream::CHANNEL_PROPERTY ).toInt() );
 }
@@ -650,9 +654,8 @@ VideoWindow::slotSetSubtitle()
 void
 VideoWindow::setAudioChannel( int channel )
 {
-    DEBUG_BLOCK
     Phonon::AudioChannelDescription desc = Phonon::AudioChannelDescription::fromIndex( channel );
-    debug() << "using index: " << channel << " returned desc has index: " << desc.index();
+    kDebug() << "using index: " << channel << " returned desc has index: " << desc.index();
     if(desc.isValid())
       m_controller->setCurrentAudioChannel( desc );
 }
@@ -660,7 +663,6 @@ VideoWindow::setAudioChannel( int channel )
 void
 VideoWindow::slotSetAudio()
 {
-    DEBUG_BLOCK
     if( sender() && sender()->property( TheStream::CHANNEL_PROPERTY ).canConvert<int>() )
         setAudioChannel( sender()->property( TheStream::CHANNEL_PROPERTY ).toInt() );
 }
@@ -684,19 +686,19 @@ int
 VideoWindow::videoSetting( const QString& setting )
 {
     double dValue = 0.0;
-    if( setting == "brightnessSlider" )
+    if( setting == QLatin1String( "brightnessSlider" ) )
     {
         dValue = m_vWidget->brightness();
     }
-    else if( setting == "contrastSlider" )
+    else if( setting == QLatin1String( "contrastSlider" ) )
     {
         dValue = m_vWidget->contrast();
     }
-    else if( setting == "hueSlider" )
+    else if( setting == QLatin1String( "hueSlider" ) )
     {
         dValue = m_vWidget->hue();
     }
-    else if( setting == "saturationSlider" )
+    else if( setting == QLatin1String( "saturationSlider" ) )
     {
         dValue = m_vWidget->saturation();
     }
@@ -736,15 +738,13 @@ VideoWindow::tenPercentForward()
 void
 VideoWindow::tenSecondsBack()
 {
-    qint64 newTime = m_media->currentTime() - 10000;
-    relativeSeek( newTime );
+    relativeSeek( -10000 );
 }
 
 void
 VideoWindow::tenSecondsForward()
 {
-    qint64 newTime = m_media->currentTime() + 10000;
-    relativeSeek( newTime );
+    relativeSeek( 10000 );
 }
 
 ///////////
@@ -757,7 +757,7 @@ VideoWindow::event( QEvent* event )
     switch( event->type() )
     {
       case QEvent::Leave:
-         m_cursorTimer->stop(), debug() << "stop cursorTimer";
+         m_cursorTimer->stop(); kDebug() << "stop cursorTimer";
       break;
       case QEvent::FocusOut:
          // if the user summons some dialog via a shortcut or whatever we need to ensure
@@ -767,8 +767,7 @@ VideoWindow::event( QEvent* event )
       case QEvent::Enter:
       case QEvent::MouseMove:
       case QEvent::MouseButtonPress:
-         kapp->restoreOverrideCursor();
-         if( hasFocus() )
+            kapp->restoreOverrideCursor();
             m_cursorTimer->start( CURSOR_HIDE_TIMEOUT );
          break;
       default: return QWidget::event( event );
@@ -779,7 +778,6 @@ VideoWindow::event( QEvent* event )
 void
 VideoWindow::contextMenuEvent( QContextMenuEvent * event )
 {
-    DEBUG_BLOCK
     KMenu menu;
     if( mainWindow() )
     {
@@ -821,7 +819,6 @@ VideoWindow::sizeHint() const //virtual
 void
 VideoWindow::eject()
 {
-DEBUG_BLOCK
     if( m_media->currentSource().type() == Phonon::MediaSource::Invalid )
         return;
 
@@ -854,10 +851,10 @@ DEBUG_BLOCK
         //this if clause - is to prevent a crash from bug 162721 (a Phonon bug), remove when fixed
         if(m_media->hasVideo())
         {
-          debug() << "trying to fetch subtitle information";
+          kDebug() << "trying to fetch subtitle information";
           const int subtitle = TheStream::subtitleChannel();
           const int audio = TheStream::audioChannel();
-          debug() << "fetched subtitle information";
+          kDebug() << "fetched subtitle information";
 
 
         if( subtitle != -1 )
