@@ -191,16 +191,6 @@ void KMixDockWidget::handleNewMaster(QString& /*mixerID*/, QString& /*control_id
       use deleteLater(), as we are executing in a SLOT currently.
     */
    _kmixMainWindow->updateDocking();
-/*
-    Mixer *mixer = MixerToolBox::instance()->find(mixerID);
-    if ( mixer == 0 ) {
-        kError(67100) << "KMixDockWidget::createPage(): Invalid Mixer (mixerID=" << mixerID << ")" << endl;
-        return; // can not happen
-   }
-   m_mixer = mixer;
-   //Mixer::setGlobalMaster(mixer->id(), control_id); // We must save this information "somewhere".
-   createMasterVolWidget();
-*/
 }
 
 
@@ -270,7 +260,8 @@ KMixDockWidget::updatePixmap()
         }
         long absoluteVolume    = vol.getAvgVolume(Volume::MALL);
         int percentage         = vol.percentage(absoluteVolume);
-        if      ( percentage < 25 ) newPixmapType = '1';  // Hint: also negative-values
+        if      ( percentage <= 0 ) newPixmapType = '0';  // Hint: also negative-values
+        else if ( percentage < 25 ) newPixmapType = '1';
         else if ( percentage < 75 ) newPixmapType = '2';
         else                        newPixmapType = '3';
    }
@@ -280,7 +271,8 @@ KMixDockWidget::updatePixmap()
       // Pixmap must be changed => do so
       switch ( newPixmapType ) {
          case 'e': setIconByName( "kmixdocked_error" ); break;
-         case 'm': setIconByName( "audio-volume-muted"  ); break;
+         case 'm': 
+         case '0': setIconByName( "audio-volume-muted"  ); break;
          case '1': setIconByName( "audio-volume-low"  ); break;
          case '2': setIconByName( "audio-volume-medium" ); break;
          case '3': setIconByName( "audio-volume-high" ); break;
@@ -418,8 +410,8 @@ void
 KMixDockWidget::dockMute()
 {
    MixDevice *md = Mixer::getGlobalMasterMD();
-   if ( md != 0 ) {
-      md->setMuted( !md->isMuted() );
+   if ( md ) {
+      md->toggleMute();
       md->mixer()->commitVolumeChange( md );
    }
 }
@@ -451,7 +443,7 @@ KMixDockWidget::contextMenuAboutToShow()
     // Enable/Disable "Muted" menu item
     MixDevice* md = Mixer::getGlobalMasterMD();
     KToggleAction *dockMuteAction = static_cast<KToggleAction*>(actionCollection()->action("dock_mute"));
-    kDebug(67100) << "---> md=" << md << "dockMuteAction=" << dockMuteAction << "isMuted=" << md->isMuted();
+    //kDebug(67100) << "---> md=" << md << "dockMuteAction=" << dockMuteAction << "isMuted=" << md->isMuted();
     if ( md != 0 && dockMuteAction != 0 ) {
         bool hasSwitch = md->playbackVolume().hasSwitch();
         dockMuteAction->setEnabled( hasSwitch );
