@@ -22,6 +22,8 @@
 
 #include "config-musicbrainz.h"
 
+#include <kdemacros.h> // KDE_NO_DEPRECATED
+
 #include "libkcddb/sites.h"
 #include "libkcddb/lookup.h"
 
@@ -31,7 +33,11 @@
 #include <klocale.h>
 #include <kinputdialog.h>
 #include <kmessagebox.h>
+#ifndef KDE_NO_DEPRECATED
 #include <keditlistbox.h>
+#else
+#include <keditlistwidget.h>
+#endif
 #include <kurlrequester.h>
 #include <QCheckBox>
 
@@ -49,10 +55,23 @@ CDDBConfigWidget::CDDBConfigWidget(QWidget * parent)
   KUrlRequester* urlReq = new KUrlRequester(this);
   urlReq->setMode(KFile::Directory);
 
-  KEditListBox* editListBox = new KEditListBox(i18n("Cache Locations"), urlReq->customEditor(), cacheLocationsParent, "kcfg_cacheLocations");
+  QGroupBox* groupBox = new QGroupBox(cacheLocationsParent);
+  groupBox->setTitle(i18n("Cache Locations"));
+  QVBoxLayout* gbLayout = new QVBoxLayout(groupBox);
+  gbLayout->setMargin(0);
+
+#ifndef KDE_NO_DEPRECATED
+  KEditListBox* editListWidget = new KEditListBox(groupBox);
+#else
+  KEditListWidget* editListWidget = new KEditListWidget(groupBox);
+#endif
+  editListWidget->setCustomEditor(urlReq->customEditor());
+  editListWidget->setObjectName(QString::fromLatin1("kcfg_cacheLocations"));
+  gbLayout->addWidget(editListWidget);
+
   QHBoxLayout *layout = new QHBoxLayout(cacheLocationsParent);
   layout->setMargin(0);
-  layout->addWidget(editListBox);
+  layout->addWidget(groupBox);
 
   connect(needsAuthenticationBox,SIGNAL(toggled(bool)),SLOT(needAuthenticationChanged(bool)));
   connect(kcfg_FreedbLookupTransport,SIGNAL(activated(int)),SLOT(protocolChanged()));
